@@ -57,6 +57,10 @@ class Dummy_smtplib(object):
     existing = None
 
     def __init__(self, server):
+        import warnings
+        warnings.warn(
+            'Dummy_smtplib is not maintained and is deprecated',
+            DeprecationWarning, 2)
         assert not self.existing, (
             "smtplib.SMTP() called again before Dummy_smtplib.existing.reset() "
             "called.")
@@ -177,7 +181,7 @@ class TestApp(object):
         __tracebackhide__ = True
         if params:
             if not isinstance(params, (str, unicode)):
-                params = urllib.urlencode(params)
+                params = urllib.urlencode(params, doseq=True)
             if '?' in url:
                 url += '&'
             else:
@@ -312,7 +316,7 @@ class TestApp(object):
         req.environ['paste.testing_variables'] = {}
         app = lint.middleware(self.app)
         old_stdout = sys.stdout
-        out = StringIO()
+        out = CaptureStdout(old_stdout)
         try:
             sys.stdout = out
             start_time = time.time()
@@ -376,6 +380,26 @@ class TestApp(object):
         return TestResponse(self, status, headers, body, errors,
                             total_time)
 
+class CaptureStdout(object):
+
+    def __init__(self, actual):
+        self.captured = StringIO()
+        self.actual = actual
+
+    def write(self, s):
+        self.captured.write(s)
+        self.actual.write(s)
+
+    def flush(self):
+        self.actual.flush()
+
+    def writelines(self, lines):
+        for item in lines:
+            self.write(item)
+
+    def getvalue(self):
+        return self.captured.getvalue()
+
 class TestResponse(object):
 
     # for py.test
