@@ -74,10 +74,10 @@ References:
 """
 
 import types
-from wsgilib import catch_errors_app
-from response import has_header, header_value, replace_header
-from request import resolve_relative_url
-from util.quoting import strip_html, html_quote, no_quote
+from paste.wsgilib import catch_errors_app
+from paste.response import has_header, header_value, replace_header
+from paste.request import resolve_relative_url
+from paste.util.quoting import strip_html, html_quote, no_quote
 
 SERVER_NAME = 'WSGI Server'
 TEMPLATE = """\
@@ -240,9 +240,9 @@ class HTTPException(Exception):
         if isinstance(content, unicode):
             content = content.encode('utf8')
             cur_content_type = (
-                response.header_value(headers, 'content-type')
+                header_value(headers, 'content-type')
                 or 'text/html')
-            reponse.replace_header(
+            replace_header(
                 headers, 'content-type',
                 cur_content_type + '; charset=utf8')
         start_response('%s %s' % (self.code, self.title),
