@@ -10,11 +10,12 @@ import imp
 import urllib
 import pkg_resources
 import mimetypes
-import request
-import fileapp
+from paste import request
+from paste import fileapp
 from paste.util import import_string
-import httpexceptions
+from paste import httpexceptions
 from httpheaders import ETAG
+from paste.util import converters
 
 class NoDefault:
     pass
@@ -107,7 +108,6 @@ class URLParser(object):
         self.base_python_name = base_python_name
         # This logic here should be deprecated since it is in
         # make_url_parser
-        from paste.deploy import converters
         if index_names is NoDefault:
             index_names = global_conf.get(
                 'index_names', ('index', 'Index', 'main', 'Main'))
@@ -435,6 +435,8 @@ class StaticURLParser(object):
         self.root_directory = root_directory
         if root_directory is not None:
             self.root_directory = os.path.normpath(self.root_directory)
+        else:
+            self.root_directory = os.path.normpath(directory)
         self.cache_max_age = cache_max_age
         
     def __call__(self, environ, start_response):
@@ -468,7 +470,7 @@ class StaticURLParser(object):
             if str(mytime) == if_none_match:
                 headers = []
                 ETAG.update(headers, mytime)
-                start_response('304 Not Modified',headers)
+                start_response('304 Not Modified', headers)
                 return [''] # empty body
         
         fa = fileapp.FileApp(full)
@@ -612,7 +614,6 @@ def make_url_parser(global_conf, directory, base_python_name,
     ``'.pyc'``) and ``ignore_extensions`` are viewable but only if an
     explicit extension is given.
     """
-    from paste.deploy import converters
     if index_names is None:
         index_names = global_conf.get(
             'index_names', ('index', 'Index', 'main', 'Main'))
